# SCRAPpy

Single-cell RNA Analysis Platform (SCRAP) Python Package

SCRAPpy provides common functionality for accessing and manipulating SCRAP data
via Python.

## Installation

```
pip install scrap
```
